/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package modelo.controle;

import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import modelo.Cliente;
import modelo.Funcionario;
import modelo.PedidoVenda;
import java.util.ArrayList;
import java.util.Collection;
import modelo.controle.exceptions.IllegalOrphanException;
import modelo.controle.exceptions.NonexistentEntityException;
import modelo.controle.exceptions.PreexistingEntityException;

/**
 *
 * @author willian
 */
public class ClienteJpaController {

    public ClienteJpaController() {
        emf = Persistence.createEntityManagerFactory("EstoquePU");
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Cliente cliente) throws PreexistingEntityException, Exception {
        if (cliente.getPedidoVendaCollection() == null) {
            cliente.setPedidoVendaCollection(new ArrayList<PedidoVenda>());
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Funcionario funcionario = cliente.getFuncionario();
            if (funcionario != null) {
                funcionario = em.getReference(funcionario.getClass(), funcionario.getId());
                cliente.setFuncionario(funcionario);
            }
            Collection<PedidoVenda> attachedPedidoVendaCollection = new ArrayList<PedidoVenda>();
            for (PedidoVenda pedidoVendaCollectionPedidoVendaToAttach : cliente.getPedidoVendaCollection()) {
                pedidoVendaCollectionPedidoVendaToAttach = em.getReference(pedidoVendaCollectionPedidoVendaToAttach.getClass(), pedidoVendaCollectionPedidoVendaToAttach.getId());
                attachedPedidoVendaCollection.add(pedidoVendaCollectionPedidoVendaToAttach);
            }
            cliente.setPedidoVendaCollection(attachedPedidoVendaCollection);
            em.persist(cliente);
            if (funcionario != null) {
                funcionario.getClienteCollection().add(cliente);
                funcionario = em.merge(funcionario);
            }
            for (PedidoVenda pedidoVendaCollectionPedidoVenda : cliente.getPedidoVendaCollection()) {
                Cliente oldClienteOfPedidoVendaCollectionPedidoVenda = pedidoVendaCollectionPedidoVenda.getCliente();
                pedidoVendaCollectionPedidoVenda.setCliente(cliente);
                pedidoVendaCollectionPedidoVenda = em.merge(pedidoVendaCollectionPedidoVenda);
                if (oldClienteOfPedidoVendaCollectionPedidoVenda != null) {
                    oldClienteOfPedidoVendaCollectionPedidoVenda.getPedidoVendaCollection().remove(pedidoVendaCollectionPedidoVenda);
                    oldClienteOfPedidoVendaCollectionPedidoVenda = em.merge(oldClienteOfPedidoVendaCollectionPedidoVenda);
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            if (findCliente(cliente.getId()) != null) {
                throw new PreexistingEntityException("Cliente " + cliente + " already exists.", ex);
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Cliente cliente) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Cliente persistentCliente = em.find(Cliente.class, cliente.getId());
            Funcionario funcionarioOld = persistentCliente.getFuncionario();
            Funcionario funcionarioNew = cliente.getFuncionario();
            Collection<PedidoVenda> pedidoVendaCollectionOld = persistentCliente.getPedidoVendaCollection();
            Collection<PedidoVenda> pedidoVendaCollectionNew = cliente.getPedidoVendaCollection();
            List<String> illegalOrphanMessages = null;
            for (PedidoVenda pedidoVendaCollectionOldPedidoVenda : pedidoVendaCollectionOld) {
                if (!pedidoVendaCollectionNew.contains(pedidoVendaCollectionOldPedidoVenda)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain PedidoVenda " + pedidoVendaCollectionOldPedidoVenda + " since its cliente field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (funcionarioNew != null) {
                funcionarioNew = em.getReference(funcionarioNew.getClass(), funcionarioNew.getId());
                cliente.setFuncionario(funcionarioNew);
            }
            Collection<PedidoVenda> attachedPedidoVendaCollectionNew = new ArrayList<PedidoVenda>();
            for (PedidoVenda pedidoVendaCollectionNewPedidoVendaToAttach : pedidoVendaCollectionNew) {
                pedidoVendaCollectionNewPedidoVendaToAttach = em.getReference(pedidoVendaCollectionNewPedidoVendaToAttach.getClass(), pedidoVendaCollectionNewPedidoVendaToAttach.getId());
                attachedPedidoVendaCollectionNew.add(pedidoVendaCollectionNewPedidoVendaToAttach);
            }
            pedidoVendaCollectionNew = attachedPedidoVendaCollectionNew;
            cliente.setPedidoVendaCollection(pedidoVendaCollectionNew);
            cliente = em.merge(cliente);
            if (funcionarioOld != null && !funcionarioOld.equals(funcionarioNew)) {
                funcionarioOld.getClienteCollection().remove(cliente);
                funcionarioOld = em.merge(funcionarioOld);
            }
            if (funcionarioNew != null && !funcionarioNew.equals(funcionarioOld)) {
                funcionarioNew.getClienteCollection().add(cliente);
                funcionarioNew = em.merge(funcionarioNew);
            }
            for (PedidoVenda pedidoVendaCollectionNewPedidoVenda : pedidoVendaCollectionNew) {
                if (!pedidoVendaCollectionOld.contains(pedidoVendaCollectionNewPedidoVenda)) {
                    Cliente oldClienteOfPedidoVendaCollectionNewPedidoVenda = pedidoVendaCollectionNewPedidoVenda.getCliente();
                    pedidoVendaCollectionNewPedidoVenda.setCliente(cliente);
                    pedidoVendaCollectionNewPedidoVenda = em.merge(pedidoVendaCollectionNewPedidoVenda);
                    if (oldClienteOfPedidoVendaCollectionNewPedidoVenda != null && !oldClienteOfPedidoVendaCollectionNewPedidoVenda.equals(cliente)) {
                        oldClienteOfPedidoVendaCollectionNewPedidoVenda.getPedidoVendaCollection().remove(pedidoVendaCollectionNewPedidoVenda);
                        oldClienteOfPedidoVendaCollectionNewPedidoVenda = em.merge(oldClienteOfPedidoVendaCollectionNewPedidoVenda);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = cliente.getId();
                if (findCliente(id) == null) {
                    throw new NonexistentEntityException("The cliente with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Cliente cliente;
            try {
                cliente = em.getReference(Cliente.class, id);
                cliente.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The cliente with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<PedidoVenda> pedidoVendaCollectionOrphanCheck = cliente.getPedidoVendaCollection();
            for (PedidoVenda pedidoVendaCollectionOrphanCheckPedidoVenda : pedidoVendaCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Cliente (" + cliente + ") cannot be destroyed since the PedidoVenda " + pedidoVendaCollectionOrphanCheckPedidoVenda + " in its pedidoVendaCollection field has a non-nullable cliente field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Funcionario funcionario = cliente.getFuncionario();
            if (funcionario != null) {
                funcionario.getClienteCollection().remove(cliente);
                funcionario = em.merge(funcionario);
            }
            em.remove(cliente);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Cliente> findClienteEntities() {
        return findClienteEntities(true, -1, -1);
    }

    public List<Cliente> findClienteEntities(int maxResults, int firstResult) {
        return findClienteEntities(false, maxResults, firstResult);
    }

    private List<Cliente> findClienteEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            Query q = em.createQuery("select object(o) from Cliente as o");
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Cliente findCliente(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Cliente.class, id);
        } finally {
            em.close();
        }
    }

    public int getClienteCount() {
        EntityManager em = getEntityManager();
        try {
            Query q = em.createQuery("select count(o) from Cliente as o");
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }

}
