SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `labbd` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
USE `labbd` ;

-- -----------------------------------------------------
-- Table `labbd`.`Funcionario`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`Funcionario` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`Funcionario` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nome` VARCHAR(45) NOT NULL ,
  `cpf` VARCHAR(45) NULL ,
  `nascimento` DATE NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `labbd`.`Cliente`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`Cliente` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`Cliente` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nome` VARCHAR(45) NULL ,
  `funcionario_id` INT NULL COMMENT 'Funcionário responsável pelo cliente' ,
  `telefone` VARCHAR(45) NULL ,
  `cnpj` VARCHAR(45) NULL ,
  `endereco` VARCHAR(45) NULL ,
  `cep` VARCHAR(45) NULL ,
  PRIMARY KEY (`id`) ,
  CONSTRAINT `cliente_responsavel`
    FOREIGN KEY (`funcionario_id` )
    REFERENCES `labbd`.`Funcionario` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

CREATE INDEX `cliente_responsavel` ON `labbd`.`Cliente` (`funcionario_id` ASC) ;


-- -----------------------------------------------------
-- Table `labbd`.`PedidoVenda`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`PedidoVenda` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`PedidoVenda` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `data` DATE NOT NULL ,
  `cliente_id` INT NOT NULL ,
  `funcionario_id` INT NOT NULL ,
  PRIMARY KEY (`id`) ,
  CONSTRAINT `PedidoVenda_cliente`
    FOREIGN KEY (`cliente_id` )
    REFERENCES `labbd`.`Cliente` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `PedidoVenda_funcionario`
    FOREIGN KEY (`funcionario_id` )
    REFERENCES `labbd`.`Funcionario` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

CREATE INDEX `PedidoVenda_cliente` ON `labbd`.`PedidoVenda` (`cliente_id` ASC) ;

CREATE INDEX `PedidoVenda_funcionario` ON `labbd`.`PedidoVenda` (`funcionario_id` ASC) ;


-- -----------------------------------------------------
-- Table `labbd`.`Produto`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`Produto` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`Produto` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `codigo` VARCHAR(45) NOT NULL ,
  `nome` VARCHAR(45) NOT NULL ,
  `custo` DECIMAL(10,3) NULL ,
  `preco` DECIMAL(10,3) NULL ,
  `estoque` INT NULL ,
  `classe` INT NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `labbd`.`Venda`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`Venda` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`Venda` (
  `pedidoVenda_id` INT NOT NULL ,
  `produto_id` INT NOT NULL ,
  `quantidade` DECIMAL(10,3) NOT NULL ,
  `valor_unitario` DECIMAL(10,3) NOT NULL ,
  PRIMARY KEY (`pedidoVenda_id`, `produto_id`) ,
  CONSTRAINT `fk_PedidoVenda_has_Produto_PedidoVenda1`
    FOREIGN KEY (`pedidoVenda_id` )
    REFERENCES `labbd`.`PedidoVenda` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_PedidoVenda_has_Produto_Produto1`
    FOREIGN KEY (`produto_id` )
    REFERENCES `labbd`.`Produto` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

CREATE INDEX `fk_PedidoVenda_has_Produto_Produto1` ON `labbd`.`Venda` (`produto_id` ASC) ;


-- -----------------------------------------------------
-- Table `labbd`.`PedidoProducao`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`PedidoProducao` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`PedidoProducao` (
  `id` INT NOT NULL ,
  `funcionario_id` INT NOT NULL ,
  `produto_id` INT NOT NULL ,
  `data` DATE NOT NULL ,
  `quantidade` DECIMAL(10,5) NOT NULL ,
  PRIMARY KEY (`id`) ,
  CONSTRAINT `PedidoProducao_funcionario`
    FOREIGN KEY (`funcionario_id` )
    REFERENCES `labbd`.`Funcionario` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `PedidoProducao_produto`
    FOREIGN KEY (`produto_id` )
    REFERENCES `labbd`.`Produto` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

CREATE INDEX `PedidoProducao_funcionario` ON `labbd`.`PedidoProducao` (`funcionario_id` ASC) ;

CREATE INDEX `PedidoProducao_produto` ON `labbd`.`PedidoProducao` (`produto_id` ASC) ;


-- -----------------------------------------------------
-- Table `labbd`.`Fornecedor`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`Fornecedor` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`Fornecedor` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nome` VARCHAR(45) NOT NULL ,
  `cnpj` VARCHAR(45) NULL ,
  `endereco` VARCHAR(45) NULL ,
  `cep` VARCHAR(45) NULL ,
  `cidade` VARCHAR(45) NULL ,
  `telefone` VARCHAR(45) NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `labbd`.`PedidoCompra`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`PedidoCompra` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`PedidoCompra` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `data` DATE NOT NULL ,
  `fornecedor_id` INT NOT NULL ,
  `funcionario_id` INT NOT NULL ,
  PRIMARY KEY (`id`) ,
  CONSTRAINT `PedidoCompra_funcionario`
    FOREIGN KEY (`funcionario_id` )
    REFERENCES `labbd`.`Funcionario` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fornecedor`
    FOREIGN KEY (`fornecedor_id` )
    REFERENCES `labbd`.`Fornecedor` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

CREATE INDEX `PedidoCompra_funcionario` ON `labbd`.`PedidoCompra` (`funcionario_id` ASC) ;

CREATE INDEX `fornecedor` ON `labbd`.`PedidoCompra` (`fornecedor_id` ASC) ;


-- -----------------------------------------------------
-- Table `labbd`.`Compra`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`Compra` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`Compra` (
  `pedidoCompra_id` INT NOT NULL AUTO_INCREMENT ,
  `produto_id` INT NOT NULL ,
  `quantidade` DECIMAL(10,3) NOT NULL ,
  `valor_unitario` DECIMAL(10,3) NOT NULL ,
  PRIMARY KEY (`pedidoCompra_id`, `produto_id`) ,
  CONSTRAINT `fk_PedidoCompra_has_Produto_PedidoCompra1`
    FOREIGN KEY (`pedidoCompra_id` )
    REFERENCES `labbd`.`PedidoCompra` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_PedidoCompra_has_Produto_Produto1`
    FOREIGN KEY (`produto_id` )
    REFERENCES `labbd`.`Produto` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

CREATE INDEX `fk_PedidoCompra_has_Produto_Produto1` ON `labbd`.`Compra` (`produto_id` ASC) ;


-- -----------------------------------------------------
-- Table `labbd`.`Fornece`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`Fornece` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`Fornece` (
  `Fornecedor_id` INT NOT NULL ,
  `Produto_id` INT NOT NULL ,
  `preco` DECIMAL(10,3) NULL ,
  PRIMARY KEY (`Fornecedor_id`, `Produto_id`) ,
  CONSTRAINT `fk_Fornecedor_has_Produto_Fornecedor1`
    FOREIGN KEY (`Fornecedor_id` )
    REFERENCES `labbd`.`Fornecedor` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Fornecedor_has_Produto_Produto1`
    FOREIGN KEY (`Produto_id` )
    REFERENCES `labbd`.`Produto` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

CREATE INDEX `fk_Fornecedor_has_Produto_Produto1` ON `labbd`.`Fornece` (`Produto_id` ASC) ;


-- -----------------------------------------------------
-- Table `labbd`.`Compoe`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `labbd`.`Compoe` ;

CREATE  TABLE IF NOT EXISTS `labbd`.`Compoe` (
  `produto_id` INT NOT NULL ,
  `produto_parte` INT NOT NULL ,
  `quantidade` DECIMAL(10,3) NOT NULL ,
  PRIMARY KEY (`produto_id`, `produto_parte`) ,
  CONSTRAINT `fk_Produto_has_Produto_Produto1`
    FOREIGN KEY (`produto_id` )
    REFERENCES `labbd`.`Produto` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Produto_has_Produto_Produto2`
    FOREIGN KEY (`produto_parte` )
    REFERENCES `labbd`.`Produto` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

CREATE INDEX `fk_Produto_has_Produto_Produto2` ON `labbd`.`Compoe` (`produto_parte` ASC) ;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

-- -----------------------------------------------------
-- Data for table `labbd`.`Funcionario`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`Funcionario` (`id`, `nome`, `cpf`, `nascimento`) VALUES ('1', 'Willian Gigliotti', '32584365412', '1984-09-25');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`Cliente`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`Cliente` (`id`, `nome`, `funcionario_id`, `telefone`, `cnpj`, `endereco`, `cep`) VALUES ('1', 'Lojinha', '1', '(11) 34238734', '490250123857', 'Rua Florida, 234', '05563093');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`PedidoVenda`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`PedidoVenda` (`id`, `data`, `cliente_id`, `funcionario_id`) VALUES ('1', '2010-10-24', '1', '1');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`Produto`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`Produto` (`id`, `codigo`, `nome`, `custo`, `preco`, `estoque`, `classe`) VALUES ('1', 'CCG0001', 'Computador Completo', '850', '2500', '0', '1');
INSERT INTO `labbd`.`Produto` (`id`, `codigo`, `nome`, `custo`, `preco`, `estoque`, `classe`) VALUES ('2', 'CPU0001', 'Computador CPU', '500', '1200', '2', '0');
INSERT INTO `labbd`.`Produto` (`id`, `codigo`, `nome`, `custo`, `preco`, `estoque`, `classe`) VALUES ('3', 'TEC0002', 'Teclado XFP-DF', '15', '35', '5', '0');
INSERT INTO `labbd`.`Produto` (`id`, `codigo`, `nome`, `custo`, `preco`, `estoque`, `classe`) VALUES ('4', 'MSE0032', 'Mouse RAT-TAK', '20', '45', '6', '0');
INSERT INTO `labbd`.`Produto` (`id`, `codigo`, `nome`, `custo`, `preco`, `estoque`, `classe`) VALUES ('5', 'MNT0031', 'Monitor LCD 20 pol', '300', '600', '3', '0');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`Venda`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`Venda` (`pedidoVenda_id`, `produto_id`, `quantidade`, `valor_unitario`) VALUES ('1', '2', '1', '1300');
INSERT INTO `labbd`.`Venda` (`pedidoVenda_id`, `produto_id`, `quantidade`, `valor_unitario`) VALUES ('1', '3', '2', '35');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`PedidoProducao`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`PedidoProducao` (`id`, `funcionario_id`, `produto_id`, `data`, `quantidade`) VALUES ('1', '1', '1', '2010-10-09', '2');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`Fornecedor`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`Fornecedor` (`id`, `nome`, `cnpj`, `endereco`, `cep`, `cidade`, `telefone`) VALUES ('1', 'Lojona', '43243256213', 'Rua Batista de Limeira, 234', '19600234', 'São Paulo', '(11)32352245');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`PedidoCompra`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`PedidoCompra` (`id`, `data`, `fornecedor_id`, `funcionario_id`) VALUES ('1', '2010-10-23', '1', '1');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`Compra`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`Compra` (`pedidoCompra_id`, `produto_id`, `quantidade`, `valor_unitario`) VALUES ('1', '2', '3', '500');
INSERT INTO `labbd`.`Compra` (`pedidoCompra_id`, `produto_id`, `quantidade`, `valor_unitario`) VALUES ('1', '5', '4', '310');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`Fornece`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`Fornece` (`Fornecedor_id`, `Produto_id`, `preco`) VALUES ('1', '2', '500');
INSERT INTO `labbd`.`Fornece` (`Fornecedor_id`, `Produto_id`, `preco`) VALUES ('1', '3', '20');
INSERT INTO `labbd`.`Fornece` (`Fornecedor_id`, `Produto_id`, `preco`) VALUES ('1', '5', '300');

COMMIT;

-- -----------------------------------------------------
-- Data for table `labbd`.`Compoe`
-- -----------------------------------------------------
SET AUTOCOMMIT=0;
USE `labbd`;
INSERT INTO `labbd`.`Compoe` (`produto_id`, `produto_parte`, `quantidade`) VALUES ('1', '2', '1');
INSERT INTO `labbd`.`Compoe` (`produto_id`, `produto_parte`, `quantidade`) VALUES ('1', '3', '1');
INSERT INTO `labbd`.`Compoe` (`produto_id`, `produto_parte`, `quantidade`) VALUES ('1', '4', '1');
INSERT INTO `labbd`.`Compoe` (`produto_id`, `produto_parte`, `quantidade`) VALUES ('1', '5', '1');

COMMIT;
